@@ -26,6 +26,7 @@ class AprsClient:
         # create socket, connect to server, login and make a file object associated with the socket
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
+        self.sock.settimeout(5)
 
         if self.aprs_filter:
             port = self.settings.APRS_SERVER_PORT_CLIENT_DEFINED_FILTERS
@@ -52,7 +53,7 @@ class AprsClient:
 
         self._kill = True
 
-    def run(self, callback, timed_callback=lambda client: None, autoreconnect=False):
+    def run(self, callback, timed_callback=lambda client: None, autoreconnect=False, **kwargs):
         while not self._kill:
             try:
                 keepalive_time = time()
@@ -72,13 +73,13 @@ class AprsClient:
                         self.logger.warning('Read returns zero length string. Failure.  Orderly closeout')
                         break
 
-                    callback(packet_str)
-            except ConnectionError:
-                self.logger.error('ConnectionError', exc_info=True)
-            except socket.error:
-                self.logger.error('socket.error', exc_info=True)
-            except UnicodeDecodeError:
-                self.logger.error('UnicodeDecodeError', exc_info=True)
+                    callback(packet_str, **kwargs)
+            except socket.error as e:
+                self.logger.error(f'socket.error: {e}')
+            except OSError as e:
+                self.logger.error(f'OSError: {e}')
+            except UnicodeDecodeError as e:
+                self.logger.error(f'UnicodeDecodeError: {e}')
 
             if autoreconnect and not self._kill:
                 self.connect()
